;;;
;;; $Id: tm-os2.el,v 7.20 1996/10/27 15:05:22 H.Ueno Exp $
;;;
;;; Setting a MIME extension under OS/2 environment for tm.
;;; by Hiroshi Ueno <zodiac@ibm.net>
;;;

(require 'tl-atype)
(require 'tl-str)
(require 'tl-misc)
(require 'tm-setup)

;;
;; variables
;;
(defvar tm-os2/show-x-face nil)

;;
;; For tm-view.  Define the internal and external methods for each
;; content type for MIME decoding.
;;
(call-after-loaded 'tm-view
  (function (lambda ()
;
    (if (file-installed-p "mailcrypt.el")
      (require 'tm-pgp))
;;
;; To show X-Face image inline, uncompface.exe from compface package
;; is required.
;;
    (cond ((and window-system
		tm-os2/show-x-face
		(boundp 'MULE)
		(file-installed-p "uncompface.exe" exec-path))
	  (require 'tm-image)))
;
    (set-atype 'mime/content-decoding-condition
      '((type . "text/plain")
        (method "cmd" nil "/c" "tm-plain" 'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "text/html")
        (method "cmd" nil "/c" "tm-html" 'file 'type 'encoding 'mode 'name)
	(mode . "play")))
    (set-atype 'mime/content-decoding-condition
      '((type . "audio/basic")
        (method "cmd" nil "/c" "tm-au"    'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "audio/x-aiff")
        (method "cmd" nil "/c" "tm-au"    'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "audio/x-wav")
        (method "cmd" nil "/c" "tm-au"    'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "image/gif")
        (method "cmd" nil "/c" "tm-image" 'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "image/jpeg")
        (method "cmd" nil "/c" "tm-image" 'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "image/tiff")
        (method "cmd" nil "/c" "tm-image" 'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "image/x-tiff")
        (method "cmd" nil "/c" "tm-image" 'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "image/x-xbm")
        (method "cmd" nil "/c" "tm-image" 'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "image/x-pic")
        (method "cmd" nil "/c" "tm-image" 'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "image/x-pcx")
        (method "cmd" nil "/c" "tm-image" 'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "image/x-portable-pixmap")
        (method "cmd" nil "/c" "tm-image" 'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "image/x-portable-graymap")
        (method "cmd" nil "/c" "tm-image" 'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "image/x-os2-bmp")
        (method "cmd" nil "/c" "tm-image" 'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "video/mpeg")
        (method "cmd" nil "/c" "tm-mpeg"  'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "video/x-msvideo")
        (method "cmd" nil "/c" "tm-mpeg"  'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "video/quicktime")
        (method "cmd" nil "/c" "tm-mpeg"  'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "application/octet-stream")
        (method "cmd" nil "/c" "tm-file"  'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "application/x-zip-compressed")
        (method "cmd" nil "/c" "tm-file"  'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "application/zip")
        (method "cmd" nil "/c" "tm-file"  'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "application/x-tar")
        (method "cmd" nil "/c" "tm-file"  'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "application/x-gzip")
        (method "cmd" nil "/c" "tm-file"  'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "message/rfc822")
        (method "cmd" nil "/c" "tm-file"  'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((type . "application/mac-binhex40")
        (method "cmd" nil "/c" "tm-mac"  'file 'type 'encoding 'mode 'name)))
    (set-atype 'mime/content-decoding-condition
      '((method "cmd" nil "/c" "tm-file" 'file 'type 'encoding 'mode 'name)
        (mode . "extract")))
  )))
;;
;; Set a coding system of the MIME output buffer.
;;
(cond ((boundp 'MULE)
       (define-program-coding-system "*MIME-out*" nil *autoconv*)
       )
      ((boundp 'NEMACS)
       (define-program-kanji-code "*MIME-out*" nil 'sjis)
       ))
;;
;; Add some content types for composing MIME messages.
;;
(call-after-loaded 'tm-edit
  (function (lambda ()
    (put-alist "image"
      '(("gif")
        ("jpeg")
        ("x-pic")
        ("tiff")
        ("x-pcx")
        ("x-os2-bmp")
        ("x-mag")
        ("x-xwd")
        ("x-xbm")) mime-content-types)
    (put-alist "audio"
      '(("basic")
        ("x-aiff")
        ("x-wav")) mime-content-types)
    (put-alist "video"
      '(("mpeg")
        ("x-msvideo")
        ("quicktime")) mime-content-types)

    (setq mime-file-types (append
      '(("\\.pcx$"
	 "image"    "x-pcx"      nil
	 "base64"
	 "inline"	(("filename" . file))
	 )
        ("\\.tif$"
	 "image"    "tiff"       nil
	 "base64"
	 "inline"	(("filename" . file))
	 )
        ("\\.wav$"
	 "audio"    "x-wav"      nil
	 "base64"
	 "attachment"	(("filename" . file))
	 )
        ("\\.aif$"
	 "audio"    "x-aiff"     nil
	 "base64"
 	 "attachment"	(("filename" . file))
	 )
        ("\\.mov$"
	 "video"    "quicktime"  nil
	 "base64"
	 "attachment"	(("filename" . file))
	 )
        ("\\.qt$"
	 "video"    "quicktime"  nil
	 "base64"
	 "attachment"	(("filename" . file))
	 )
        ("\\.avi$"
	 "video"    "x-msvideo"  nil
	 "base64"
	 "attachment"	(("filename" . file))
	))
      mime-file-types))
;;
;; Redefine the program coding system of uuencode-external-encoder
;;
    (cond ((boundp 'MULE)
           (require 'mel-u)
           (define-program-coding-system
             nil (car uuencode-external-encoder) '(*autoconv* . *noconv*))
          ))
  )))
;;
;; List of invalid characters for filename.
;;
(setq filename-special-char-range
      (nconc '((0 . 31))
	     (string-to-int-list "\"")
	     (list (cons (char-int ?&) (char-int ?*)))
	     (string-to-int-list ",/")
	     (list (cons (char-int ?:) (char-int ??)))
	     (string-to-int-list "\\^`")
	     (list (cons (char-int ?{) (char-int ?})))
	     '((127 . 255))))
;;
;; Override uuencode-external-decoder
;;
(setq mime/tmp-dir (or (getenv "TM_TMP_DIR")
		       (getenv "TMP") "./"))
(setq uuencode-external-decoder
  (list "cmd" "/c" (format "cd %s & uudecode" mime/tmp-dir)))

;;
;; Override x-gzip64 encoder/decode
;;
(setq gzip64-external-encoder '("cmd" "/c" "gzip -c | mmencode"))
(setq gzip64-external-decoder '("cmd" "/c" "mmencode -u | gzip -dc"))

(require 'mel-g)
;;
;; end of tm-os2.el
;;
(provide 'tm-os2)
